@@ -151,7 +151,7 @@ class ASGIRouter:
 
         validate_node(node=self.root_route_map_node)
         if self._mount_routes:
-            self._mount_paths_regex = re.compile("|".join(sorted(set(self._mount_routes))))
+            self._mount_paths_regex = re.compile("|".join(sorted(set(self._mount_routes))))  # pyright: ignore
 
     async def lifespan(self, receive: "LifeSpanReceive", send: "LifeSpanSend") -> None:
         """Handle the ASGI "lifespan" event on application startup and shutdown.
@@ -172,7 +172,7 @@ class ASGIRouter:
                 startup_event: "LifeSpanStartupCompleteEvent" = {"type": "lifespan.startup.complete"}
                 await send(startup_event)
                 await receive()
-            else:
+            else:  # pragma: no cover
                 await self.shutdown()
                 await send(shutdown_event)
         except BaseException as e:
@@ -182,16 +182,16 @@ class ASGIRouter:
                     "message": format_exc(),
                 }
                 await send(startup_failure_event)
-            else:
+            else:  # pragma: no cover
                 shutdown_failure_event: "LifeSpanShutdownFailedEvent" = {
                     "type": "lifespan.shutdown.failed",
                     "message": format_exc(),
                 }
                 await send(shutdown_failure_event)
             raise e
-        else:
-            await self.shutdown()
-            await send(shutdown_event)
+
+        await self.shutdown()
+        await send(shutdown_event)
 
     async def startup(self) -> None:
         """Run any [LifeSpanHandlers][starlite.types.LifeSpanHandler] defined in the application's `.on_startup` list.
