@@ -1,6 +1,5 @@
 from typing import TYPE_CHECKING
 
-from starlite.asgi.routing_trie.types import PathParameterSentinel
 from starlite.exceptions import ImproperlyConfiguredException
 
 if TYPE_CHECKING:
@@ -19,11 +18,11 @@ def validate_node(node: "RouteTrieNode") -> None:
     Returns:
         None
     """
-    if node["is_asgi"] and bool(set(node["asgi_handlers"]).difference({"asgi"})):
+    if node.is_asgi and bool(set(node.asgi_handlers).difference({"asgi"})):
         raise ImproperlyConfiguredException("ASGI handlers must have a unique path not shared by other route handlers.")
 
-    if node["is_static"] and PathParameterSentinel in node["child_keys"]:
-        raise ImproperlyConfiguredException("Path parameters cannot be configured for a static path.")
+    if node.is_mount and node.children and any(child.path_parameters for child in node.children.values()):
+        raise ImproperlyConfiguredException("Path parameters are not allowed under a static or mount route.")
 
-    for child in node["children"].values():
+    for child in node.children.values():
         validate_node(node=child)
