@@ -7,9 +7,9 @@ EXTRA_KEY_SKIP_VALIDATION = "skip_validation"
 EXTRA_KEY_VALUE_TYPE = "value_type"
 HTTP_RESPONSE_BODY = "http.response.body"
 HTTP_RESPONSE_START = "http.response.start"
+ONE_MEGABYTE = 1024 * 1024
 REDIRECT_STATUS_CODES = {301, 302, 303, 307, 308}
-RESERVED_KWARGS = {"state", "headers", "cookies", "request", "socket", "data", "query", "scope"}
+RESERVED_KWARGS = {"state", "headers", "cookies", "request", "socket", "data", "query", "scope", "body"}
 SCOPE_STATE_DEPENDENCY_CACHE = "dependency_cache"
 SCOPE_STATE_NAMESPACE = "__starlite__"
 SCOPE_STATE_RESPONSE_COMPRESSED = "response_compressed"
-ONE_MEGABYTE: int = 1024 * 1024
