@@ -224,7 +224,7 @@ def _create_data_handler(
         if is_dto_annotation and not isinstance(data, DTO):
             data = return_annotation(**data) if isinstance(data, dict) else return_annotation.from_model_instance(data)
 
-        elif is_dto_iterable_annotation and not isinstance(data[0], DTO):  # pyright: ignore
+        elif is_dto_iterable_annotation and data and not isinstance(data[0], DTO):  # pyright: ignore
             dto_type = cast("Type[DTO]", get_args(return_annotation)[0])
             data = [
                 dto_type(**datum) if isinstance(datum, dict) else dto_type.from_model_instance(datum) for datum in data
@@ -808,6 +808,7 @@ class get(HTTPRouteHandler):
             summary: Text used for the route's schema summary section.
             tags: A list of string tags that will be appended to the OpenAPI schema.
                        type_encoders: A mapping of types to callables that transform them into types supported for serialization.
+            type_encoders: A mapping of types to callables that transform them into types supported for serialization.
             **kwargs: Any additional kwarg - will be set in the opt dictionary.
         """
         if "http_method" in kwargs:
