@@ -13,9 +13,10 @@ except ImportError as e:
 
 
 class QueueListenerHandler(QueueHandler):
+    """Configure queue listener and handler to support non-blocking logging configuration."""
+
     def __init__(self, handlers: Optional[List[Any]] = None) -> None:
-        """Configures queue listener and handler to support non-blocking
-        logging configuration.
+        """Initialize `QueueListenerHandler`.
 
         Args:
             handlers: Optional 'ConvertingList'
