@@ -1,11 +1,20 @@
-import re
 from abc import abstractmethod
-from typing import TYPE_CHECKING, Any, Callable, List, Optional, Pattern, Union
-
-from typing_extensions import Protocol, runtime_checkable
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    List,
+    Optional,
+    Protocol,
+    Union,
+    runtime_checkable,
+)
 
 from starlite.enums import ScopeType
-from starlite.middleware.utils import should_bypass_middleware
+from starlite.middleware.utils import (
+    build_exclude_path_pattern,
+    should_bypass_middleware,
+)
 
 if TYPE_CHECKING:
     from starlite.types import Scopes
@@ -14,12 +23,14 @@ if TYPE_CHECKING:
 
 @runtime_checkable
 class MiddlewareProtocol(Protocol):  # pragma: no cover
+    """Abstract middleware protocol."""
+
     __slots__ = ("app",)
 
     app: "ASGIApp"
 
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """Executes the ASGI middleware.
+        """Execute the ASGI middleware.
 
         Called by the previous middleware in the stack if a response is not awaited prior.
 
@@ -37,6 +48,8 @@ class MiddlewareProtocol(Protocol):  # pragma: no cover
 
 
 class DefineMiddleware:
+    """Container enabling passing *args and **kwargs to Middleware class constructors and factory functions."""
+
     __slots__ = (
         "middleware",
         "args",
@@ -44,8 +57,7 @@ class DefineMiddleware:
     )
 
     def __init__(self, middleware: Callable[..., "ASGIApp"], *args: Any, **kwargs: Any) -> None:
-        """This class is a container that allows passing *args and **kwargs to
-        Middleware class constructors and factory functions.
+        """Initialize `DefineMiddleware`.
 
         Args:
             middleware: A callable that returns an ASGIApp.
@@ -61,7 +73,7 @@ class DefineMiddleware:
         self.kwargs = kwargs
 
     def __call__(self, app: "ASGIApp") -> "ASGIApp":
-        """Calls the middleware constructor or factory.
+        """Call the middleware constructor or factory.
 
         Args:
             app: An ASGIApp, this value is the next ASGI handler to call in the middleware stack.
@@ -74,6 +86,12 @@ class DefineMiddleware:
 
 
 class AbstractMiddleware:
+    """Abstract middleware providing base functionality common to all middlewares, for dynamically engaging/bypassing
+    the middleware based on paths, `opt`-keys and scope types.
+
+    When implementing new middleware, this class should be used as a base.
+    """
+
     scopes: "Scopes" = {ScopeType.HTTP, ScopeType.WEBSOCKET}
     exclude: Optional[Union[str, List[str]]] = None
     exclude_opt_key: Optional[str] = None
@@ -85,7 +103,7 @@ class AbstractMiddleware:
         exclude_opt_key: Optional[str] = None,
         scopes: Optional["Scopes"] = None,
     ) -> None:
-        """
+        """Initialize the middleware.
 
         Args:
             app: The 'next' ASGI app to call.
@@ -99,12 +117,7 @@ class AbstractMiddleware:
         self.app = app
         self.scopes = scopes or self.scopes
         self.exclude_opt_key = exclude_opt_key or self.exclude_opt_key
-
-        self.exclude_pattern: Optional[Pattern] = None
-
-        exclude = exclude or self.exclude
-        if exclude is not None:
-            self.exclude_pattern = re.compile("|".join(exclude)) if isinstance(exclude, list) else re.compile(exclude)
+        self.exclude_pattern = build_exclude_path_pattern(exclude=(exclude or self.exclude))
 
     @classmethod
     def __init_subclass__(cls, **kwargs: Any) -> None:
@@ -128,7 +141,7 @@ class AbstractMiddleware:
 
     @abstractmethod
     async def __call__(self, scope: "Scope", receive: "Receive", send: "Send") -> None:
-        """Executes the ASGI middleware.
+        """Execute the ASGI middleware.
 
         Called by the previous middleware in the stack if a response is not awaited prior.
 
