@@ -1,6 +1,7 @@
 from datetime import datetime
 from decimal import Decimal
 from enum import Enum, EnumMeta
+from re import Pattern
 from typing import TYPE_CHECKING, Any, List, Optional, Type, Union
 
 from pydantic import (
@@ -116,7 +117,7 @@ def create_string_constrained_field_schema(field_type: Union[Type[ConstrainedStr
         schema.minLength = field_type.min_length
     if field_type.max_length:
         schema.maxLength = field_type.max_length
-    if issubclass(field_type, ConstrainedStr) and field_type.regex is not None:
+    if issubclass(field_type, ConstrainedStr) and isinstance(field_type.regex, Pattern):
         schema.pattern = field_type.regex.pattern
     if field_type.to_lower:
         schema.description = "must be in lower case"
@@ -208,7 +209,7 @@ def get_schema_for_field_type(field: ModelField, plugins: List["PluginProtocol"]
         return OpenAPI310PydanticSchema(schema_class=convert_dataclass_to_model(field_type))
     if is_typeddict_typeguard(field_type):
         return OpenAPI310PydanticSchema(schema_class=convert_typeddict_to_model(field_type))
-    if isinstance(field_type, EnumMeta):
+    if isinstance(field_type, (EnumMeta, Enum)):
         enum_values: List[Union[str, int]] = [v.value for v in field_type]  # type: ignore
         openapi_type = OpenAPIType.STRING if isinstance(enum_values[0], str) else OpenAPIType.INTEGER
         return Schema(type=openapi_type, enum=enum_values)
@@ -307,7 +308,7 @@ def create_examples_for_field(field: ModelField) -> List[Example]:
     try:
         value = normalize_example_value(ExampleFactory.get_field_value(field))
         return [Example(description=f"Example {field.name} value", value=value)]
-    except ParameterError:
+    except ParameterError:  # pragma: no cover
         return []
 
 
@@ -356,7 +357,7 @@ def create_schema(
                 for sub_field in field.sub_fields
             ]
             if len(items) > 1:
-                schema.items = Schema(oneOf=items)  # type: ignore[arg-type]
+                schema.items = Schema(oneOf=items)  # type: ignore[arg-type] # pragma: no cover
             else:
                 schema.items = items[0]
     elif field.shape == SHAPE_GENERIC:
