@@ -99,6 +99,6 @@ class TortoiseORMPlugin(PluginProtocol[Model]):
         data = await pydantic_model_class.from_tortoise_orm(model_instance)
         return cast("Dict[str, Any]", data.dict())
 
-    def from_dict(self, model_class: Type[Model], **kwargs: Any) -> Model:
+    def from_dict(self, model_class: Type[Model], **kwargs: Any) -> Model:  # pragma: no cover
         """Given a class supported by this plugin and a dict of values, create an instance of the class."""
         return model_class().update_from_dict(**kwargs)
