@@ -25,6 +25,8 @@ if TYPE_CHECKING:
 
 
 class StreamingResponse(Response[StreamType[Union[str, bytes]]]):
+    """An HTTP response that streams the response data as a series of ASGI 'http.response.body' events."""
+
     __slots__ = ("iterator",)
 
     def __init__(
@@ -39,8 +41,7 @@ class StreamingResponse(Response[StreamType[Union[str, bytes]]]):
         encoding: str = "utf-8",
         is_head_response: bool = False,
     ):
-        """This class is an HTTP response that streams the response data as a
-        series of ASGI 'http.response.body' events.
+        """Initialize the response.
 
         Args:
             content: A sync or async iterator or iterable.
@@ -69,8 +70,7 @@ class StreamingResponse(Response[StreamType[Union[str, bytes]]]):
         )
 
     async def _listen_for_disconnect(self, cancel_scope: "CancelScope", receive: "Receive") -> None:
-        """
-        Listens for a cancellation message, and if received - calls cancel on the cancel scope.
+        """Listen for a cancellation message, and if received - call cancel on the cancel scope.
 
         Args:
             cancel_scope: A task group cancel scope instance.
@@ -89,8 +89,7 @@ class StreamingResponse(Response[StreamType[Union[str, bytes]]]):
                 await self._listen_for_disconnect(cancel_scope=cancel_scope, receive=receive)
 
     async def _stream(self, send: "Send") -> None:
-        """Sends the chunks from the iterator as a stream of ASGI
-        'http.response.body' events.
+        """Send the chunks from the iterator as a stream of ASGI 'http.response.body' events.
 
         Args:
             send: The ASGI Send function.
@@ -109,7 +108,7 @@ class StreamingResponse(Response[StreamType[Union[str, bytes]]]):
         await send(terminus_event)
 
     async def send_body(self, send: "Send", receive: "Receive") -> None:
-        """Emits a stream of events correlating with the response body.
+        """Emit a stream of events correlating with the response body.
 
         Args:
             send: The ASGI send function.
